aboutsummaryrefslogtreecommitdiff
path: root/include/wlr
diff options
context:
space:
mode:
Diffstat (limited to 'include/wlr')
-rw-r--r--include/wlr/types/meson.build4
-rw-r--r--include/wlr/types/wlr_layer_shell_v1.h (renamed from include/wlr/types/wlr_layer_shell.h)69
-rw-r--r--include/wlr/types/wlr_xdg_output_v1.h (renamed from include/wlr/types/wlr_xdg_output.h)14
3 files changed, 44 insertions, 43 deletions
diff --git a/include/wlr/types/meson.build b/include/wlr/types/meson.build
index 8c81cb0e..6a8955c3 100644
--- a/include/wlr/types/meson.build
+++ b/include/wlr/types/meson.build
@@ -12,7 +12,7 @@ install_headers(
'wlr_input_device.h',
'wlr_input_inhibitor.h',
'wlr_keyboard.h',
- 'wlr_layer_shell.h',
+ 'wlr_layer_shell_v1.h',
'wlr_linux_dmabuf_v1.h',
'wlr_list.h',
'wlr_matrix.h',
@@ -35,7 +35,7 @@ install_headers(
'wlr_wl_shell.h',
'wlr_xcursor_manager.h',
'wlr_xdg_decoration_v1.h',
- 'wlr_xdg_output.h',
+ 'wlr_xdg_output_v1.h',
'wlr_xdg_shell.h',
'wlr_xdg_shell_v6.h',
subdir: 'wlr/types',
diff --git a/include/wlr/types/wlr_xdg_output.h b/include/wlr/types/wlr_xdg_output_v1.h
index 60611307..d4279fb9 100644
--- a/include/wlr/types/wlr_xdg_output.h
+++ b/include/wlr/types/wlr_xdg_output_v1.h
@@ -6,13 +6,13 @@
#error "Add -DWLR_USE_UNSTABLE to enable unstable wlroots features"
#endif
-#ifndef WLR_TYPES_WLR_XDG_OUTPUT_H
-#define WLR_TYPES_WLR_XDG_OUTPUT_H
+#ifndef WLR_TYPES_WLR_XDG_OUTPUT_V1_H
+#define WLR_TYPES_WLR_XDG_OUTPUT_V1_H
#include <wayland-server.h>
#include <wlr/types/wlr_output_layout.h>
-struct wlr_xdg_output {
- struct wlr_xdg_output_manager *manager;
+struct wlr_xdg_output_v1 {
+ struct wlr_xdg_output_manager_v1 *manager;
struct wl_list resources;
struct wl_list link;
@@ -24,7 +24,7 @@ struct wlr_xdg_output {
struct wl_listener destroy;
};
-struct wlr_xdg_output_manager {
+struct wlr_xdg_output_manager_v1 {
struct wl_global *global;
struct wl_list resources;
struct wlr_output_layout *layout;
@@ -40,8 +40,8 @@ struct wlr_xdg_output_manager {
} events;
};
-struct wlr_xdg_output_manager *wlr_xdg_output_manager_create(
+struct wlr_xdg_output_manager_v1 *wlr_xdg_output_manager_v1_create(
struct wl_display *display, struct wlr_output_layout *layout);
-void wlr_xdg_output_manager_destroy(struct wlr_xdg_output_manager *manager);
+void wlr_xdg_output_manager_v1_destroy(struct wlr_xdg_output_manager_v1 *manager);
#endif
diff --git a/include/wlr/types/wlr_layer_shell.h b/include/wlr/types/wlr_layer_shell_v1.h
index c7ddd180..838b2e83 100644
--- a/include/wlr/types/wlr_layer_shell.h
+++ b/include/wlr/types/wlr_layer_shell_v1.h
@@ -6,8 +6,8 @@
#error "Add -DWLR_USE_UNSTABLE to enable unstable wlroots features"
#endif
-#ifndef WLR_TYPES_WLR_LAYER_SHELL_H
-#define WLR_TYPES_WLR_LAYER_SHELL_H
+#ifndef WLR_TYPES_WLR_LAYER_SHELL_V1_H
+#define WLR_TYPES_WLR_LAYER_SHELL_V1_H
#include <stdbool.h>
#include <stdint.h>
#include <wayland-server.h>
@@ -16,28 +16,28 @@
#include "wlr-layer-shell-unstable-v1-protocol.h"
/**
* wlr_layer_shell allows clients to arrange themselves in "layers" on the
* desktop in accordance with the wlr-layer-shell protocol. When a client is
* added, the new_surface signal will be raised and passed a reference to our
* wlr_layer_surface. At this time, the client will have configured the surface
* as it desires, including information like desired anchors and margins. The
* compositor should use this information to decide how to arrange the layer
* on-screen, then determine the dimensions of the layer and call
* wlr_layer_surface_configure. The client will then attach a buffer and commit
* the surface, at which point the wlr_layer_surface map signal is raised and
* the compositor should begin rendering the surface.
*/
-struct wlr_layer_shell {
+struct wlr_layer_shell_v1 {
struct wl_global *global;
- struct wl_list client_resources; // wl_resource
+ struct wl_list resources; // wl_resource
struct wl_list surfaces; // wl_layer_surface
struct wl_listener display_destroy;
struct {
// struct wlr_layer_surface *
// Note: the output may be NULL. In this case, it is your
// responsibility to assign an output before returning.
struct wl_signal new_surface;
struct wl_signal destroy;
} events;
@@ -45,7 +45,7 @@ struct wlr_layer_shell {
void *data;
};
-struct wlr_layer_surface_state {
+struct wlr_layer_surface_v1_state {
uint32_t anchor;
int32_t exclusive_zone;
struct {
@@ -56,18 +56,18 @@ struct wlr_layer_surface_state {
uint32_t actual_width, actual_height;
};
-struct wlr_layer_surface_configure {
- struct wl_list link; // wlr_layer_surface::configure_list
+struct wlr_layer_surface_v1_configure {
+ struct wl_list link; // wlr_layer_surface_v1::configure_list
uint32_t serial;
- struct wlr_layer_surface_state state;
+ struct wlr_layer_surface_v1_state state;
};
-struct wlr_layer_surface {
- struct wl_list link; // wlr_layer_shell::surfaces
+struct wlr_layer_surface_v1 {
+ struct wl_list link; // wlr_layer_shell_v1::surfaces
struct wlr_surface *surface;
struct wlr_output *output;
struct wl_resource *resource;
- struct wlr_layer_shell *shell;
+ struct wlr_layer_shell_v1 *shell;
struct wl_list popups; // wlr_xdg_popup::link
char *namespace;
@@ -79,11 +79,11 @@ struct wlr_layer_surface {
uint32_t configure_next_serial;
struct wl_list configure_list;
- struct wlr_layer_surface_configure *acked_configure;
+ struct wlr_layer_surface_v1_configure *acked_configure;
- struct wlr_layer_surface_state client_pending;
- struct wlr_layer_surface_state server_pending;
- struct wlr_layer_surface_state current;
+ struct wlr_layer_surface_v1_state client_pending;
+ struct wlr_layer_surface_v1_state server_pending;
+ struct wlr_layer_surface_v1_state current;
struct wl_listener surface_destroy;
@@ -97,29 +97,29 @@ struct wlr_layer_surface {
void *data;
};
-struct wlr_layer_shell *wlr_layer_shell_create(struct wl_display *display);
-void wlr_layer_shell_destroy(struct wlr_layer_shell *layer_shell);
+struct wlr_layer_shell_v1 *wlr_layer_shell_v1_create(struct wl_display *display);
+void wlr_layer_shell_v1_destroy(struct wlr_layer_shell_v1 *layer_shell);
/**
* Notifies the layer surface to configure itself with this width/height. The
* layer_surface will signal its map event when the surface is ready to assume
* this size.
*/
-void wlr_layer_surface_configure(struct wlr_layer_surface *surface,
+void wlr_layer_surface_v1_configure(struct wlr_layer_surface_v1 *surface,
uint32_t width, uint32_t height);
/**
* Unmaps this layer surface and notifies the client that it has been closed.
*/
-void wlr_layer_surface_close(struct wlr_layer_surface *surface);
+void wlr_layer_surface_v1_close(struct wlr_layer_surface_v1 *surface);
bool wlr_surface_is_layer_surface(struct wlr_surface *surface);
-struct wlr_layer_surface *wlr_layer_surface_from_wlr_surface(
+struct wlr_layer_surface_v1 *wlr_layer_surface_v1_from_wlr_surface(
struct wlr_surface *surface);
/* Calls the iterator function for each sub-surface and popup of this surface */
-void wlr_layer_surface_for_each_surface(struct wlr_layer_surface *surface,
+void wlr_layer_surface_v1_for_each_surface(struct wlr_layer_surface_v1 *surface,
wlr_surface_iterator_func_t iterator, void *user_data);
/**
@@ -127,7 +127,8 @@ void wlr_layer_surface_for_each_surface(struct wlr_layer_surface *surface,
* coordinates. Returns the surface and coordinates in the leaf surface
* coordinate system or NULL if no surface is found at that location.
*/
-struct wlr_surface *wlr_layer_surface_surface_at(
- struct wlr_layer_surface *surface, double sx, double sy,
+struct wlr_surface *wlr_layer_surface_v1_surface_at(
+ struct wlr_layer_surface_v1 *surface, double sx, double sy,
double *sub_x, double *sub_y);
+
#endif
@@ -16,28 +16,28 @@
#include "wlr-layer-shell-unstable-v1-protocol.h"
/**
- * wlr_layer_shell allows clients to arrange themselves in "layers" on the
+ * wlr_layer_shell_v1 allows clients to arrange themselves in "layers" on the
* desktop in accordance with the wlr-layer-shell protocol. When a client is
* added, the new_surface signal will be raised and passed a reference to our
@@ -16,28 +16,28 @@
* desktop in accordance with the wlr-layer-shell protocol. When a client is
* added, the new_surface signal will be raised and passed a reference to our
- * wlr_layer_surface. At this time, the client will have configured the surface
- * as it desires, including information like desired anchors and margins. The
- * compositor should use this information to decide how to arrange the layer
- * on-screen, then determine the dimensions of the layer and call
- * wlr_layer_surface_configure. The client will then attach a buffer and commit
- * the surface, at which point the wlr_layer_surface map signal is raised and
- * the compositor should begin rendering the surface.
+ * wlr_layer_surface_v1. At this time, the client will have configured the
+ * surface as it desires, including information like desired anchors and
+ * margins. The compositor should use this information to decide how to arrange
+ * the layer on-screen, then determine the dimensions of the layer and call
+ * wlr_layer_surface_v1_configure. The client will then attach a buffer and
+ * commit the surface, at which point the wlr_layer_surface_v1 map signal is
+ * raised and the compositor should begin rendering the surface.
*/
@@ -16,28 +16,28 @@
struct wl_listener display_destroy;
struct {
- // struct wlr_layer_surface *
- // Note: the output may be NULL. In this case, it is your
- // responsibility to assign an output before returning.
+ // struct wlr_layer_surface_v1 *
+ // Note: the output may be NULL. In this case, it is your
+ // responsibility to assign an output before returning.
struct wl_signal new_surface;
struct wl_signal destroy;